﻿using System;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;

namespace TestProject
{
    /// <summary>
    /// 메인 윈도우
    /// </summary>
    public partial class MainWindow : Window
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainWindow()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();

            this.border.MouseLeftButtonDown  += border_mouseLeftButtonDown;
            this.border.MouseRightButtonDown += border_mouseRightButtonDown;                
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 테두리 마우스 왼쪽 버튼 DOWN 처리하기 - border_mouseLeftButtonDown(sender, e)

        /// <summary>
        /// 테두리 마우스 왼쪽 버튼 DOWN 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void border_mouseLeftButtonDown(object sender, MouseButtonEventArgs e)
        {
            Point mousePoint = Mouse.GetPosition(this.border);
            
            Point targetPoint = new Point();

            targetPoint.X = mousePoint.X - ellipse.Width  / 2;
            targetPoint.Y = mousePoint.Y - ellipse.Height / 2;
            
            DoubleAnimation doubleAnimationX = new DoubleAnimation
            (
                targetPoint.X, 
                new Duration(TimeSpan.FromSeconds(4))
            );

            this.translateTransform.BeginAnimation
            (
                TranslateTransform.XProperty,
                doubleAnimationX,
                HandoffBehavior.SnapshotAndReplace
            );
                
            DoubleAnimation doubleAnimationY = new DoubleAnimation
            (
                targetPoint.Y,
                new Duration(TimeSpan.FromSeconds(4))
            );

            this.translateTransform.BeginAnimation
            (
                TranslateTransform.YProperty,
                doubleAnimationY,
                HandoffBehavior.SnapshotAndReplace
            );

            this.ellipse.Fill = Brushes.Lime;
        }

        #endregion
        #region 테두리 마우스 오른쪽 버튼 DOWN 처리하기 - border_mouseRightButtonDown(sender, e)

        /// <summary>
        /// 테두리 마우스 오른쪽 버튼 DOWN 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void border_mouseRightButtonDown(object sender, MouseButtonEventArgs e)
        {
            Point mousePoint = Mouse.GetPosition(this.border);
            
            Point targetPoint = new Point();

            targetPoint.X = mousePoint.X - ellipse.Width  / 2;
            targetPoint.Y = mousePoint.Y - ellipse.Height / 2;

            DoubleAnimation doubleAnimationX = new DoubleAnimation
            (
                targetPoint.X, 
                new Duration(TimeSpan.FromSeconds(4))
            );

            this.translateTransform.BeginAnimation
            (
                TranslateTransform.XProperty,
                doubleAnimationX,
                HandoffBehavior.Compose
            );
                
            DoubleAnimation doubleAnimationY = new DoubleAnimation
            (
                targetPoint.Y, 
                new Duration(TimeSpan.FromSeconds(4))
            );

            this.translateTransform.BeginAnimation
            (
                TranslateTransform.YProperty,
                doubleAnimationY,
                HandoffBehavior.Compose
            );
                
            this.ellipse.Fill = Brushes.Orange;
        }

        #endregion
    }
}